/***************************************************************************
                          main.h  -  description
                             -------------------
    begin                : Die Nov 9 2004
    copyright            : (C) 2004 by 
    email                : 
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MAIN_H
#define MAIN_H

#include "globdefines.h"
#include "listviews.hpp"
#include "spl_prg.hpp"
#include <plib/ssg.h>

extern int g_mouse_mode;
extern int g_mouse_x;
extern int g_mouse_y;
extern int g_mouse_button;
extern sgVec3 g_poi;
extern int g_window_w;
extern int g_window_h;
extern QSet<int> g_keyset;
extern int g_key;
extern int g_playmode;
extern int g_switch;
extern long g_nextid;
extern bool g_debug;

extern class aStar *gastar;
extern class netclient    *g_client;
extern class Glcontrol    *g_gl;
extern class FolderListItem *g_tmpItem;
extern class FolderListItem * g_switchScene;
extern class QString g_prjpath;
extern class QString g_3dcatalogpath;
extern class QString g_scriptcatalogpath;
extern int g_3dcatalogkategorie;
extern class QString g_soundcatalogpath;
extern class QString g_shadercatalogpath;
extern class QString g_physikcatalogpath;

extern class QString g_apppath;
extern class Messages *g_messages;
// Display
extern int g_displayfps;
extern int g_displayphfps;
#endif
